lu-dj-utils (LookUP.cl's Django utilities)
==================================================

.. image:: https://secure.travis-ci.org/lookup/lu-dj-utils.png?branch=master
   :target: http://travis-ci.org/lookup/lu-dj-utils
.. image:: https://coveralls.io/repos/lookup/lu-dj-utils/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/lookup/lu-dj-utils?branch=master
.. image:: https://img.shields.io/pypi/v/lu-dj-utils.svg
   :target: https://pypi.python.org/pypi/lu-dj-utils/
   :alt: Latest version

LookUP.cl's open source utilities for use in Django projects.


License
-------

This software is licensed under the OSI-approved "BSD License". To avoid
confusion with the original BSD license from 1990, the FSF refers to it as
"Modified BSD License". Other names include "New BSD", "revised BSD", "BSD-3",
or "3-clause BSD".

See the included LICENSE.txt file.


Run tests
---------

At the project root directory run:

.. code-block:: console

    python setup.py test

To test the project in all the supported Python environments run:

.. code-block:: console

    tox
